@@ -181,6 +181,7 @@ class Client(Buildin):
         """
         assert self.is_connected() is False
         assert self._reconnecting is False
+        assert len(pool), 'pool must contain at least one node'
         if len(auth) == 1:
             auth = auth[0]
 
@@ -338,6 +339,8 @@ class Client(Buildin):
             is_bin: bool = False,
             timeout: Optional[int] = None
     ) -> asyncio.Future:
+        if not self._pool:
+            raise ConnectionError('no connection')
         while True:
             if not self.is_connected():
                 logging.info('Wait for a connection')
